#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var fs = require("fs-extra");
var child_process = require("child_process");
var glob = require("glob");
var path = require("path");
var yaml = require("js-yaml");
var program = require("commander");
var src;
var repoRelativePath;
var dest = 'docs-ref-autogen';
var packageWhiteList = [];
var packageBlackList = [];
var config;
var pjson = require('../package.json');
var envPath = process.env['APPDATA'] + "/npm/node_modules/ts-reference-ci-scripts";
program
    .version("v" + pjson.version)
    .description('A tool to go through source code and convert it to yaml data model for docfx.')
    .option('--config [value]', 'The config file which will defined more specefied behaviour for the tool')
    .option('--destPath [value]', 'Path to output the autogen files.')
    .arguments('<sourceFolder> [repoConfigPath]')
    .action(function (sourceFolder, repoConfig) {
    src = sourceFolder;
    repoRelativePath = repoConfig;
})
    .parse(process.argv);
if (!src) {
    console.log('Error: The source file folder is not specified!');
    program.help();
}
if (program.config) {
    try {
        config = JSON.parse(program.config);
    }
    catch (e) {
        console.log("Invalid json format of config, ignored! content: " + program.config);
    }
}
if (config) {
    if (config.package_white_list) {
        packageWhiteList = config.package_white_list;
    }
    if (config.package_black_list) {
        packageBlackList = config.package_black_list;
    }
    if (config.npm_package_sources && config.npm_package_sources.length) {
        config.npm_package_sources.forEach(function (npmPackageSource) {
            var npmPackageSourceName = npmPackageSource.name.trim();
            child_process.execSync("npm install " + npmPackageSourceName + " 2>&1");
            fs.copySync("node_modules/" + npmPackageSourceName, src + "/" + npmPackageSourceName);
        });
    }
}
if (program.destPath) {
    if (config.target_repo.folder) {
        dest = program.destPath + "/" + config.target_repo.folder + "/" + dest;
    }
    else {
        dest = program.destPath + "/" + dest;
    }
}
// 1. prepare
fs.removeSync(dest);
fs.mkdirpSync(dest);
var packagePaths = glob.sync(path.join(src, '**/package.json'));
var toc = [];
var jsdocConfig = require('../config/node2docfx.json');
packagePaths.forEach(function (packagePath) {
    var dir = path.dirname(packagePath);
    if (!fs.existsSync(packagePath)) {
        return;
    }
    var packageName = fs.readJsonSync(packagePath).name;
    if (packageWhiteList.length === 0 || packageWhiteList.indexOf(packageName) >= 0) {
        if (packageBlackList.indexOf(packageName) >= 0) {
            return;
        }
        generatePackageDoc(packagePath, packageName, dest, jsdocConfig);
    }
});
toc = JSON.parse(JSON.stringify(toc));
fs.writeFileSync(dest + "/toc.yml", yaml.safeDump(toc));
process.exit(0);
function generatePackageDoc(packagePath, packageName, dest, config) {
    console.log(packagePath);
    var dir = path.dirname(packagePath);
    config.package = packagePath;
    config.readme = path.join(dir, 'README.md');
    config.destination = path.join(dest, packageName);
    fs.writeJsonSync('_node2docfx_temp.json', config);
    child_process.execSync('node2docfx ' + '_node2docfx_temp.json');
    console.log('Finish generating YAML files for ' + packageName);
}
